@@ -17,7 +17,9 @@
  */
 
 #include "config.h"
+#define NEEDS_BABL_DB
 #include "babl-internal.h"
+#include "babl-db.h"
 #include <stddef.h>
 #include <string.h>
 #include <stdarg.h>
